@@ -1,8 +1,12 @@
 # -*- coding: utf-8 -*-
+import time
 import json
 import requests
+from requests.exceptions import ConnectionError
+from functools import wraps
+
 from pagador import settings
-from pagador.acesso.request_mock import RequestsMock
+from pagador.acesso import request_mock
 from pagador.envio.notificador import grava_evidencia_envio
 from pagador.seguranca.autenticador import Credenciais, TipoAutenticacao, TipoConexao
 
@@ -19,6 +23,46 @@ class FormatoDeEnvio(object):
     xml = 4
 
 
+def retry(exception_to_check, tries=4, delay=3, backoff=2, logger=None):
+    """Retry calling the decorated function using an exponential backoff.
+
+    http://www.saltycrane.com/blog/2009/11/trying-out-retry-decorator-python/
+    original from: http://wiki.python.org/moin/PythonDecoratorLibrary#Retry
+
+    :param exception_to_check: the exception to check. may be a tuple of
+        exceptions to check
+    :type exception_to_check: Exception or tuple
+    :param tries: number of times to try (not retry) before giving up
+    :type tries: int
+    :param delay: initial delay between retries in seconds
+    :type delay: int
+    :param backoff: backoff multiplier e.g. value of 2 will double the delay
+        each retry
+    :type backoff: int
+    :param logger: logger to use. If None, print
+    :type logger: logging.Logger instance
+    """
+    def deco_retry(f):
+        @wraps(f)
+        def f_retry(*args, **kwargs):
+            mtries, mdelay = tries, delay
+            while mtries > 1:
+                try:
+                    return f(*args, **kwargs)
+                except exception_to_check, e:
+                    msg = "%s, Retrying in %d seconds..." % (str(e), mdelay)
+                    if logger:
+                        logger.warning(msg)
+                    else:
+                        print msg
+                    time.sleep(mdelay)
+                    mtries -= 1
+                    mdelay *= backoff
+            return f(*args, **kwargs)
+        return f_retry
+    return deco_retry
+
+
 class Conexao(object):
     def __init__(self, meio_pagamento, configuracao_pagamento, servico, tipo="envio", processar_resposta=None):
         self.tipo = tipo
@@ -44,6 +88,21 @@ class Conexao(object):
                 return autenticacao
         return requisicao_url
 
+    @retry(ConnectionError, tries=3, delay=2, backoff=2)
+    def faz_request(self, metodo, url):
+        if self.servico.formato_de_envio == FormatoDeEnvio.querystring:
+            resposta = getattr(requests, metodo)(url, params=self.dados_envio, headers=self.headers, timeout=settings.REQUEST_BASE_TIMEOUT)
+        elif self.servico.formato_de_envio == FormatoDeEnvio.form_urlencode:
+            resposta = getattr(requests, metodo)(url, data=self.dados_envio, headers=self.headers, timeout=settings.REQUEST_BASE_TIMEOUT)
+        elif self.servico.formato_de_envio == FormatoDeEnvio.xml:
+            resposta = getattr(requests, metodo)(url, data=self.dados_envio["dados"], headers=self.headers, timeout=settings.REQUEST_BASE_TIMEOUT)
+        else:
+            dados_envio = self.dados_envio
+            if type(self.dados_envio is dict):
+                dados_envio = json.dumps(self.dados_envio)
+            resposta = getattr(requests, metodo)(url, data=dados_envio, headers=self.headers, timeout=settings.REQUEST_BASE_TIMEOUT)
+        return resposta
+
     def request(self, metodo=TipoMetodo.post, segunda_tentativa=False, passo=None):
         url = self.define_url_com_autenticacao(atualiza_autenticacao=segunda_tentativa)
         dados = self.servico.gerar_dados_de_envio(passo=passo)
@@ -52,20 +111,7 @@ class Conexao(object):
                 self.dados_envio.update(dados)
             else:
                 self.dados_envio["dados"] = dados
-        if self.servico.formato_de_envio == FormatoDeEnvio.querystring:
-            resposta = getattr(requests, metodo)(url, params=self.dados_envio, headers=self.headers)
-        elif self.servico.formato_de_envio == FormatoDeEnvio.form_urlencode:
-            resposta = getattr(requests, metodo)(url, data=self.dados_envio, headers=self.headers)
-        elif self.servico.formato_de_envio == FormatoDeEnvio.xml:
-            if self.meio_pagamento == "rede":
-                resposta = getattr(RequestsMock(), metodo)(url, data=self.dados_envio["dados"], headers=self.headers)
-            else:
-                resposta = getattr(requests, metodo)(url, data=self.dados_envio["dados"], headers=self.headers)
-        else:
-            dados_envio = self.dados_envio
-            if type(self.dados_envio is dict):
-                dados_envio = json.dumps(self.dados_envio)
-            resposta = getattr(requests, metodo)(url, data=dados_envio, headers=self.headers)
+        resposta = self.faz_request(metodo, url)
         if self.processar_resposta:
             resposta = self.processar_resposta(resposta)
         if settings.GRAVA_EVIDENCIA and self.tipo == TipoConexao.envio:
