@@ -62,7 +62,7 @@ class ValidadorBase(object):
 
 class CampoFormulario(object):
     def __init__(self, nome, label, bound=True, descricao=None, requerido=False, tipo=TipoDeCampo.texto, formato=FormatoDeCampo.texto,
-                 tamanho_min=None, tamanho_max=None, ordem=0, texto_ajuda=None, opcoes=(), grupo=None, valor_padrao=None, validador=None):
+                 tamanho_min=None, tamanho_max=None, ordem=0, texto_ajuda=None, opcoes=(), grupo=None, valor_padrao=None, validador=None, decimais=2):
         self.bound = bound
         self.ordem = ordem
         self.nome = nome
@@ -78,6 +78,7 @@ class CampoFormulario(object):
         self.grupo = grupo
         self.valor_padrao = valor_padrao
         self.validador = validador
+        self.decimais = decimais
 
     def to_dict(self):
         return {
@@ -94,6 +95,7 @@ class CampoFormulario(object):
             "opcoes": self.opcoes,
             "grupo": self.grupo,
             "valor_padrao": self.valor_padrao,
+            "decimais": self.decimais,
         }
 
 
@@ -170,7 +172,7 @@ class ValoresBase(FormularioBase):
             valor = self.fields[field].valor_padrao
         if not valor is None:
             if self.fields[field].tipo == TipoDeCampo.decimal:
-                valor = '{0:.2f}'.format(valor)
+                valor = '{0:.{1}f}'.format(valor, self.fields[field].decimais)
             if self.fields[field].formato == FormatoDeCampo.json and valor:
                 valor = json.dumps(valor)
         return valor
@@ -182,5 +184,6 @@ class CadastroBase(object):
 
 
 class SelecaoBase(object):
-    def __init__(self, configuracao):
+    def __init__(self, configuracao, dados=None):
+        self.dados = dados
         self.configuracao = configuracao
\ No newline at end of file
