@@ -60,6 +60,39 @@ class Enviar(object):
         valor_subtotal = self.pedido.valor_subtotal or Decimal("0.00")
         return valor_subtotal - self.valor_desconto
 
+    @property
+    def nome_do_cliente(self):
+        nome = self.pedido.cliente.nome
+        nome = self.formatador.trata_nome(nome)
+        return self.formatador.trata_unicode_com_limite(nome, limite=50, ascii=True, trata_espaco_duplo=True)
+
+    @property
+    def telefone_do_cliente(self):
+        telefone = None
+        if self.pedido.cliente.telefone_principal:
+            telefone = self.pedido.cliente.telefone_principal
+        elif self.pedido.cliente.telefone_comercial:
+            telefone = self.pedido.cliente.telefone_comercial
+        elif self.pedido.cliente.telefone_celular:
+            telefone = self.pedido.cliente.telefone_celular
+        if telefone:
+            return self.formatador.converte_tel_em_tupla_com_ddd(telefone)
+        return '', ''
+
+    @property
+    def documento_de_cliente(self):
+        if self.pedido.cliente.endereco.tipo == "PF":
+            return self.pedido.cliente.endereco.cpf
+        else:
+            return self.pedido.cliente.endereco.cnpj
+
+    @property
+    def nome_para_entrega(self):
+        if self.pedido.endereco_entrega.tipo == "PF":
+            return self.formatador.trata_nome(self.pedido.endereco_entrega.nome)
+        else:
+            return self.formatador.trata_nome(self.pedido.endereco_entrega.razao_social)
+
 
 class EnviarPedido(Plugavel):
     def __init__(self, pedido_numero, dados, conta_id, configuracao_pagamento):
